@@ -6,7 +6,7 @@ no warnings qw(void once uninitialized numeric);
 package Moops;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.034';
+our $VERSION   = '0.035';
 
 use Exporter::Tiny qw(mkopt);
 use Keyword::Simple qw();
@@ -838,6 +838,10 @@ You can apply your trait using:
 
 =head1 BUGS
 
+If seeing test failures on threaded Perl 5.21+, it may be a bug in
+L<Devel::CallParser> 0.002.
+Try installing L<Alt::Devel::CallParser::ButWorking>.
+
 Please report any other bugs to
 L<http://rt.cpan.org/Dist/Display.html?Queue=Moops>.
 
